@@ -1,5 +1,5 @@
 
-from typing import Optional
+from typing import Optional, Tuple
 from paramak import RotateMixedShape
 
 
@@ -33,6 +33,8 @@ class CenterColumnShieldFlatTopCircular(RotateMixedShape):
         stl_filename: Optional[str] = "CenterColumnShieldFlatTopCircular.stl",
         name: Optional[str] = "center_column",
         material_tag: Optional[str] = "center_column_shield_mat",
+        color: Optional[Tuple[float, float, float,
+                              Optional[float]]] = (0., 0.333, 0.),
         **kwargs
     ) -> None:
 
@@ -41,6 +43,7 @@ class CenterColumnShieldFlatTopCircular(RotateMixedShape):
             material_tag=material_tag,
             stp_filename=stp_filename,
             stl_filename=stl_filename,
+            color=color,
             **kwargs
         )
 
