@@ -1,5 +1,5 @@
 
-from typing import Optional
+from typing import Optional, Tuple
 
 from paramak import Shape
 from paramak.utils import calculate_wedge_cut
@@ -29,12 +29,14 @@ class ExtrudeMixedShape(Shape):
         extrusion_start_offset: Optional[float] = 0.0,
         stp_filename: Optional[str] = "ExtrudeMixedShape.stp",
         stl_filename: Optional[str] = "ExtrudeMixedShape.stl",
+        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.2, 0.627, 0.172),
         **kwargs
     ):
 
         super().__init__(
             stp_filename=stp_filename,
             stl_filename=stl_filename,
+            color=color,
             **kwargs
         )
         self.distance = distance
@@ -89,6 +91,11 @@ class ExtrudeMixedShape(Shape):
             distance=extrusion_distance,
             both=self.extrude_both)
 
+        # filleting rectangular port cutter edges
+        # must be done before azimuthal placement
+        if hasattr(self, "add_fillet"):
+            solid = self.add_fillet(solid)
+
         solid = self.rotate_solid(solid)
         cutting_wedge = calculate_wedge_cut(self)
         solid = self.perform_boolean_operations(solid, wedge_cut=cutting_wedge)
