@@ -27,8 +27,8 @@ class TestInnerTfCoilsCircular(unittest.TestCase):
         assert self.test_shape.rotation_axis == "Z"
 
     def test_points_calculation(self):
-        """Checks that the points used to construct the InnerTFCoilsCircular component
-        are calculated correctly from the parameters given."""
+        """Checks that the points used to construct the InnerTFCoilsCircular
+        component are calculated correctly from the parameters given."""
 
         assert self.test_shape.points == [
             (49.937460888595446, 2.5, 'circle'),
@@ -37,6 +37,20 @@ class TestInnerTfCoilsCircular(unittest.TestCase):
             (77.154447582418, 128.6358861991937, 'circle'),
             (129.90375269002172, 75.00010024693078, 'circle'),
             (149.97916521970643, 2.5, 'straight'),
+        ]
+
+    def test_processed_points_calculation(self):
+        """Checks that the processed_points used to construct the
+        InnerTFCoilsCircular component are calculated correctly from the
+        parameters given."""
+
+        assert self.test_shape.processed_points == [
+            (49.937460888595446, 2.5, 'circle'),
+            (43.300748759659555, 25.000903120744287, 'circle'),
+            (27.1320420790315, 41.99824154201773, 'straight'),
+            (77.154447582418, 128.6358861991937, 'circle'),
+            (129.90375269002172, 75.00010024693078, 'circle'),
+            (149.97916521970643, 2.5, 'straight'),
             (49.937460888595446, 2.5, 'circle')
         ]
 
