@@ -98,19 +98,6 @@ class TestShape(unittest.TestCase):
 
         assert graveyard_volume_2 > graveyard_volume_1
 
-    def test_export_h5m_makes_dagmc_file(self):
-        """Makes a NeutronicsModel from a shapes, then makes the h5m file"""
-
-        # tests method using class attribute
-        os.system('rm dagmc.h5m')
-        self.my_shape.export_h5m()
-        assert Path('dagmc.h5m').exists() is True
-
-        # tests method using method argument
-        os.system('rm dagmc.h5m')
-        self.my_shape.export_h5m(method='pymoab')
-        assert Path('dagmc.h5m').exists() is True
-
     def test_shape_default_properties(self):
         """Creates a Shape object and checks that the points attribute has
         a default of None."""
@@ -795,25 +782,6 @@ class TestShape(unittest.TestCase):
         # TODO this can be removed in the future
         assert data[0]['stp_filename'] == 'test_shape.stp'
 
-    def test_export_vtk(self):
-        """Creates vtk files from the h5m files and checks they exist"""
-
-        os.system('rm *.h5m *.vtk')
-
-        assert self.my_shape.h5m_filename is None
-        self.my_shape.export_h5m_with_pymoab()
-        self.my_shape.export_vtk()
-        assert Path('dagmc.h5m').is_file
-        assert Path('dagmc.vtk').is_file
-        assert Path('dagmc_no_graveyard.vtk').is_file
-        assert self.my_shape.h5m_filename == 'dagmc.h5m'
-
-        self.my_shape.export_vtk(filename='custom_filename.vtk')
-        assert Path('custom_filename.vtk').is_file
-
-        self.my_shape.export_vtk(filename='suffixless_filename')
-        assert Path('suffixless_filename.vtk').is_file
-
     def test_export_vtk_without_h5m_raises_error(self):
         """exports a h5m file when shapes_and_components is set to a string"""
 
@@ -893,6 +861,23 @@ class TestShape(unittest.TestCase):
             (200, 100),
         ]
 
+    def test_cubit_h5m_export(self):
+        """exports a h5m file using cubit and checks that it has been created"""
+
+        os.system("rm test_dagmc.h5m")
+
+        my_shape = paramak.Plasma(
+            major_radius=620,
+            minor_radius=210,
+            triangularity=0.33,
+            elongation=1.85,
+            rotation_angle=90,
+        )
+
+        my_shape.export_h5m_with_cubit(filename='test_dagmc.h5m')
+
+        assert Path('test_dagmc.h5m').is_file()
+
 
 if __name__ == "__main__":
     unittest.main()
